==> tt-rss_1.5.11+dfsg.orig.tar.gz: tt-rss-1.5.11+dfsg/help/main.php <==
	<h1><?php echo __("Keyboard Shortcuts") ?></h1>

	<table style='width : 100%'><tr><td style='width : 50%' valign='top'>

	<h2><?php echo __("Navigation") ?></h2>

	<table>
		<tr><td class='n'>j/k</td><td><?php echo __("Move between feeds") ?></td></tr>
		<tr><td class='n'>n/p</td><td><?php echo __("Move between articles") ?></td></tr>
		<tr><td class='n'>/</td><td><?php echo __("Show search dialog") ?></td></tr>
	</table>

	<h2><?php echo __("Active article actions") ?></h2>

	<table>
		<tr><td class='n'>s</td><td><?php echo __("Toggle starred") ?></td></tr>
		<tr><td class='n'>S</td><td><?php echo __("Toggle published") ?></td></tr>
		<tr><td class='n'>u</td><td><?php echo __("Toggle unread") ?></td></tr>
		<tr><td class='n'>T</td><td><?php echo __("Edit tags") ?></td></tr>
		<tr><td class='n'>D</td><td><?php echo __("Dismiss selected articles") ?></td></tr>
		<tr><td class='n'>X</td><td><?php echo __("Dismiss read articles") ?></td></tr>
		<tr><td class='n'>o</td><td><?php echo __("Open article in new window") ?></td></tr>
		<tr><td class='n'>c n/c p</td><td><?php echo __("Mark articles below/above active one as read") ?></td></tr>
		<tr><td class='n'>N/P</td><td><?php echo __("Scroll article content") ?></td></tr>
		<tr><td class='n'>e</td><td><?php echo __("Email article") ?></td></tr>

	</table>

	<h2><?php echo __("Other actions") ?></h2>

	<table>
		<tr><td class='n'>[tab]</td><td><?php echo __("Select article under mouse cursor") ?></td></tr>
		<tr><td class='n'>c l</td><td><?php echo __("Create label") ?></td></tr>
		<tr><td class='n'>c f</td><td><?php echo __("Create filter") ?></td></tr>
		<tr><td class='n'>c s</td><td><?php echo __("Collapse sidebar") ?></td></tr>
		<tr><td class='n'>?</td><td><?php echo __("Display this help dialog") ?></td></tr>
	</table>

	</td><td valign='top'>

	<h2><?php echo __("Multiple articles actions") ?></h2>

	<table>
		<tr><td class='n'>a a</td><td><?php echo __("Select all articles") ?></td></tr>
		<tr><td class='n'>a u</td><td><?php echo __("Select unread articles") ?></td></tr>
		<tr><td class='n'>a i</td><td><?php echo __("Invert article selection") ?></td></tr>
		<tr><td class='n'>a n</td><td><?php echo __("Deselect all articles") ?></td></tr>
	</table>

	<h2><?php echo __("Feed actions") ?></h2>

	<table>
		<tr><td class='n'>f r</td><td><?php echo __("Refresh active feed") ?></td></tr>
		<tr><td class='n'>f a</td><td><?php echo __("(Un)hide read feeds") ?></td></tr>
		<tr><td class='n'>f s</td><td><?php echo __("Subscribe to feed") ?></td></tr>
		<tr><td class='n'>f e</td><td><?php echo __("Edit feed") ?></td></tr>
		<tr><td class='n'>f q</td><td><?php echo __("Mark feed as read") ?></td></tr>
		<tr><td class='n'>f x</td><td><?php echo __("Reverse headlines order") ?></td></tr>
		<tr><td class='n'>Q</td><td><?php echo __("Mark all feeds as read") ?></td></tr>
		<tr><td class='n'>x</td><td><?php echo __("If viewing category, (un)collapse it") ?></td></tr>
	</table>

	<h2><?php echo __("Go to...") ?></h2>

	<table>
		<tr><td class='n'>g a</td><td><?php echo __("All articles") ?></td></tr>
		<tr><td class='n'>g f</td><td><?php echo __("Fresh articles") ?></td></tr>
		<tr><td class='n'>g s</td><td><?php echo __("Starred articles") ?></td></tr>
		<tr><td class='n'>g p</td><td><?php echo __("Published articles") ?></td></tr>
		<tr><td class='n'>g t</td><td><?php echo __("Tag cloud") ?></td></tr>
		<tr><td class='n'>g P</td><td><?php echo __("Preferences") ?></td></tr>
	</table>


	</td></tr></table>

	<p><a target="_blank" href="http://tt-rss.org/wiki/InterfaceTips"><?php echo __("Other interface tips are available in the Tiny Tiny RSS wiki.") ?></a></p>

	<p class="small"><?php echo __("Press any key to close this window.") ?></p>

==> tt-rss_1.6.2+dfsg.orig.tar.gz: tt-rss-1.6.2+dfsg/help/main.php <==
	<h1><?php echo __("Keyboard Shortcuts") ?></h1>

	<table style='width : 100%'><tr><td style='width : 50%' valign='top'>

	<h2><?php echo __("Navigation") ?></h2>

	<table>
		<tr><td class='n'>j/k</td><td><?php echo __("Move between feeds") ?></td></tr>
		<tr><td class='n'>n/p</td><td><?php echo __("Move between articles") ?></td></tr>
		<tr><td class='n'>/</td><td><?php echo __("Show search dialog") ?></td></tr>
	</table>

	<h2><?php echo __("Active article actions") ?></h2>

	<table>
		<tr><td class='n'>s</td><td><?php echo __("Toggle starred") ?></td></tr>
		<tr><td class='n'>S</td><td><?php echo __("Toggle published") ?></td></tr>
		<tr><td class='n'>u</td><td><?php echo __("Toggle unread") ?></td></tr>
		<tr><td class='n'>T</td><td><?php echo __("Edit tags") ?></td></tr>
		<tr><td class='n'>D</td><td><?php echo __("Dismiss selected articles") ?></td></tr>
		<tr><td class='n'>X</td><td><?php echo __("Dismiss read articles") ?></td></tr>
		<tr><td class='n'>o</td><td><?php echo __("Open article in new window") ?></td></tr>
		<tr><td class='n'>c n/c p</td><td><?php echo __("Mark articles below/above active one as read") ?></td></tr>
		<tr><td class='n'>N/P</td><td><?php echo __("Scroll article content") ?></td></tr>
		<tr><td class='n'>e</td><td><?php echo __("Email article") ?></td></tr>

	</table>

	<h2><?php echo __("Other actions") ?></h2>

	<table>
		<tr><td class='n'>[tab]</td><td><?php echo __("Select article under mouse cursor") ?></td></tr>
		<tr><td class='n'>c l</td><td><?php echo __("Create label") ?></td></tr>
		<tr><td class='n'>c f</td><td><?php echo __("Create filter") ?></td></tr>
		<tr><td class='n'>c s</td><td><?php echo __("Collapse sidebar") ?></td></tr>
		<tr><td class='n'>?</td><td><?php echo __("Display this help dialog") ?></td></tr>
	</table>

	</td><td valign='top'>

	<h2><?php echo __("Multiple articles actions") ?></h2>

	<table>
		<tr><td class='n'>a a</td><td><?php echo __("Select all articles") ?></td></tr>
		<tr><td class='n'>a u</td><td><?php echo __("Select unread articles") ?></td></tr>
		<tr><td class='n'>a U</td><td><?php echo __("Select starred articles") ?></td></tr>
		<tr><td class='n'>a p</td><td><?php echo __("Select published articles") ?></td></tr>
		<tr><td class='n'>a i</td><td><?php echo __("Invert article selection") ?></td></tr>
		<tr><td class='n'>a n</td><td><?php echo __("Deselect all articles") ?></td></tr>
	</table>

	<h2><?php echo __("Feed actions") ?></h2>

	<table>
		<tr><td class='n'>f r</td><td><?php echo __("Refresh active feed") ?></td></tr>
		<tr><td class='n'>f a</td><td><?php echo __("(Un)hide read feeds") ?></td></tr>
		<tr><td class='n'>f s</td><td><?php echo __("Subscribe to feed") ?></td></tr>
		<tr><td class='n'>f e</td><td><?php echo __("Edit feed") ?></td></tr>
		<tr><td class='n'>f q</td><td><?php echo __("Mark feed as read") ?></td></tr>
		<tr><td class='n'>f x</td><td><?php echo __("Reverse headlines order") ?></td></tr>
		<tr><td class='n'>Q</td><td><?php echo __("Mark all feeds as read") ?></td></tr>
		<tr><td class='n'>x</td><td><?php echo __("If viewing category, (un)collapse it") ?></td></tr>
	</table>

	<h2><?php echo __("Go to...") ?></h2>

	<table>
		<tr><td class='n'>g a</td><td><?php echo __("All articles") ?></td></tr>
		<tr><td class='n'>g f</td><td><?php echo __("Fresh articles") ?></td></tr>
		<tr><td class='n'>g s</td><td><?php echo __("Starred articles") ?></td></tr>
		<tr><td class='n'>g p</td><td><?php echo __("Published articles") ?></td></tr>
		<tr><td class='n'>g t</td><td><?php echo __("Tag cloud") ?></td></tr>
		<tr><td class='n'>g P</td><td><?php echo __("Preferences") ?></td></tr>
	</table>


	</td></tr></table>

	<p><a target="_blank" href="http://tt-rss.org/wiki/InterfaceTips"><?php echo __("Other interface tips are available in the Tiny Tiny RSS wiki.") ?></a></p>

	<p class="small"><?php echo __("Press any key to close this window.") ?></p>
